@@ -1,9 +1,10 @@
-import os.path
+import os
 import shutil
 import sys
 from pathlib import Path
 from sys import exit
 from sys import platform
+import textwrap
 
 from cloudmesh.common.Shell import Shell
 from cloudmesh.common.console import Console
@@ -14,6 +15,7 @@ from cloudmesh.configuration.Config import Config
 from cloudmesh.mongo.MongoDBController import MongoDBController
 from cloudmesh.shell.command import PluginCommand
 from cloudmesh.shell.command import command
+from cloudmesh.mongo.CmDatabase import CmDatabase
 
 
 class InitCommand(PluginCommand):
@@ -47,9 +49,35 @@ class InitCommand(PluginCommand):
                     first installation
         """
 
-        if arguments.CLOUD == "yaml":
+        ssh_key = path_expand("~/.ssh/id_rsa.pub")
+        if not os.path.exists(ssh_key):
+            Console.error(f"The ssh key {ssh_key} does not exist.")
+            print()
 
-            config = Config()
+            Console.info(
+                "cms init is a convenient program to set up cloudmesh"
+                " with defaukt values. Please make sure you use ssh-keygen"
+                " to set up the keys.\n\n"
+                "      Additionally we recommend that you use. \n\n"
+                "        cms test\n\n"
+                "      to identify other issues\n")
+            return ""
+
+        config = Config()
+
+        if config["cloudmesh.profile.user"] == "TBD":
+            Console.info(
+                "cms init is a convenient program to set up cloudmesh"
+                " with defaukt values. Please make sure you use in your"
+                " ~/.cloudmesh/yaml file a valid value for\n\n"
+                "        cloudmesh.profile.user\n\n"
+                "      This name is aslo used as keyname in the cloud providers\n\n"
+                "      Additionally we recommend that you use. \n\n"
+                "        cms test\n\n"
+                "      to identify other issues\n")
+            return ""
+
+        if arguments.CLOUD == "yaml":
 
             location = path_expand("~/.cloudmesh/cloudmesh.yaml")
             path = Path(location)
@@ -68,7 +96,6 @@ class InitCommand(PluginCommand):
 
         else:
             variables = Variables()
-            config = Config()
 
             if config["cloudmesh.data.mongo.MODE"] != 'running':
                 try:
@@ -95,6 +122,10 @@ class InitCommand(PluginCommand):
                 os.system("cms admin mongo start")
             else:
                 print("MongoDB is on \"running\" mode!")
+                print("Dropping cloudmesh database...")
+                cm_db = CmDatabase()
+                cm_db.connect()
+                cm_db.drop_database()
 
             user = config["cloudmesh.profile.user"]
 
